@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 module Data.Validity.Set where
@@ -16,7 +15,6 @@ instance (Ord v, Validity v) => Validity (Set v) where
       [ declare "The set structure is valid." $ S.valid s,
         annotate (S.toList s) "Set elements"
       ]
-#if MIN_VERSION_containers(0,6,0)
-distinctOrd :: Ord a => [a] -> Bool
+
+distinctOrd :: (Ord a) => [a] -> Bool
 distinctOrd ls = nubOrd ls == ls
-#endif
